pub struct StyleXOptions {Show 32 fields
pub style_resolution: Option<String>,
pub enable_font_size_px_to_rem: Option<bool>,
pub runtime_injection: Option<RuntimeInjectionUnion>,
pub class_name_prefix: Option<String>,
pub defined_stylex_css_variables: Option<FxHashMap<String, String>>,
pub import_sources: Option<Vec<ImportSourceUnion>>,
pub treeshake_compensation: Option<bool>,
pub enable_inlined_conditional_merge: Option<bool>,
pub enable_media_query_order: Option<bool>,
pub enable_logical_styles_polyfill: Option<bool>,
pub enable_legacy_value_flipping: Option<bool>,
pub enable_ltr_rtl_comments: Option<bool>,
pub legacy_disable_layers: Option<bool>,
pub dev: Option<bool>,
pub test: Option<bool>,
pub debug: Option<bool>,
pub enable_debug_class_names: Option<bool>,
pub enable_debug_data_prop: Option<bool>,
pub enable_dev_class_names: Option<bool>,
pub enable_minified_keys: Option<bool>,
pub inject_stylex_side_effects: Option<bool>,
pub use_real_file_for_source: Option<bool>,
pub aliases: Option<FxHashMap<String, Vec<String>>>,
pub unstable_module_resolution: Option<StyleXModuleResolution>,
pub source_map: Option<SourceMaps>,
pub include: Option<Vec<UnknownRef>>,
pub exclude: Option<Vec<UnknownRef>>,
pub swc_plugins: Option<Vec<UnknownRef>>,
pub property_validation_mode: Option<PropertyValidationMode>,
pub env: Option<JsObject>,
pub debug_file_path: Option<UnknownRef>,
pub sx_prop_name: Option<SxPropNameUnion>,
}Fields
style_resolution: Option<String>enable_font_size_px_to_rem: Option<bool>runtime_injection: Option<RuntimeInjectionUnion>class_name_prefix: Option<String>defined_stylex_css_variables: Option<FxHashMap<String, String>>import_sources: Option<Vec<ImportSourceUnion>>treeshake_compensation: Option<bool>enable_inlined_conditional_merge: Option<bool>enable_media_query_order: Option<bool>enable_logical_styles_polyfill: Option<bool>enable_legacy_value_flipping: Option<bool>enable_ltr_rtl_comments: Option<bool>legacy_disable_layers: Option<bool>dev: Option<bool>test: Option<bool>debug: Option<bool>enable_debug_class_names: Option<bool>enable_debug_data_prop: Option<bool>enable_dev_class_names: Option<bool>enable_minified_keys: Option<bool>inject_stylex_side_effects: Option<bool>use_real_file_for_source: Option<bool>aliases: Option<FxHashMap<String, Vec<String>>>unstable_module_resolution: Option<StyleXModuleResolution>source_map: Option<SourceMaps>include: Option<Vec<UnknownRef>>exclude: Option<Vec<UnknownRef>>swc_plugins: Option<Vec<UnknownRef>>property_validation_mode: Option<PropertyValidationMode>env: Option<JsObject>Compile-time constants and functions accessible via stylex.env.
debug_file_path: Option<UnknownRef>Optional function or string to transform file paths used in debug class names / source maps.
sx_prop_name: Option<SxPropNameUnion>The prop name to use as the sx shorthand (default: "sx"). Set to false to disable.